local MODNAME = ...

-------------------------------------------------------------------------------
-- Localized Lua globals
-------------------------------------------------------------------------------
local _G = getfenv(0)
local format = _G.format
local pairs = _G.pairs


local Syllabus = LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local version = Syllabus.version

-- Util functions
local function err(...) Syllabus:err(...) end

-- Localizations
local L = LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local prof_idx = { prof1 = nil, prof2 = nil, arch = nil, cook = nil, firstaid = nil, fish = nil }
local prof_name = {}
function Syllabus:SetupOptions()

	local options = {
		name = format("\124TInterface\\Icons\\INV_Misc_Book_01:0:0\124t %s - %s",MODNAME,version),
		type = "group",
		order = 1,
		icon = "Interface\\Icons\\INV_Misc_Book_01",
		args = {
			prof_filter = {
				type = 'header',
				name = L["Active Skill Tracking"],
				desc = L["Select which skill should be tracked"],
				order = 0.1,
			},
			show_prof1 = {
				name      = function()
					-- Init the indexes
					prof_idx.prof1, prof_idx.prof2,
					prof_idx.arch,  prof_idx.fish,
					prof_idx.cook,  prof_idx.firstaid	= _G.GetProfessions()
					-- Find the names
					for prof, idx in pairs(prof_idx) do
						prof_name[prof] = idx and _G.GetProfessionInfo(idx) or nil
					end
					return prof_name['prof1'] or _G.PROFESSIONS_FIRST_PROFESSION
				end,
				type      = 'toggle',
				disabled  = function() return not prof_idx['prof1'] end,
				order     = 0.2,
			},
			show_prof2 = {
				name      = function() return prof_name['prof2'] or _G.PROFESSIONS_SECOND_PROFESSION end,
				type      = 'toggle',
				disabled  = function() return not prof_idx['prof2'] end,
				order     = 0.3,
			},
			show_arch = {
				name      = _G.PROFESSIONS_ARCHAEOLOGY,
				type      = 'toggle',
				disabled  = function() return not prof_idx['arch'] end,
				order     = 0.4,
			},
			show_cook = {
				name      = _G.PROFESSIONS_COOKING,
				type      = 'toggle',
				disabled  = function() return not prof_idx['cook'] end,
				order     = 0.5,
			},
			show_firstaid = {
				name      = _G.PROFESSIONS_FIRST_AID,
				type      = 'toggle',
				disabled  = function() return not prof_idx['firstaid'] end,
				order     = 0.6,
			},
			show_fish = {
				name      = _G.PROFESSIONS_FISHING,
				type      = 'toggle',
				disabled  = function() return not prof_idx['fish'] end,
				order     = 0.7,
			},
			show_class = {
				name      = _G.CLASS .. ": " .. _G.UnitClass("player"),
				type      = 'toggle',
				order     = 0.8,
			},
			broker_display = {
				type = 'header',
				name = L["Broker Display"],
				desc = L["Specify what to display on the data broker bar"],
				order = 1,
			},
			broker_learnable = {
				name      = L["Number of learnable skills"],
				desc      = L["Display the total number of skills that can be learned"],
				type      = 'toggle',
				order     = 1.1,
			},
			broker_cost = {
				name      = L["Cost to learn skills"],
				desc      = L["Choose how the cost to learn is displayed on the data broker"],
				type      = 'select',
				values	 = { base = L['Base Cost'], cheapest = L['Cheapest Cost'], none = L['None'] },
				order     = 1.2,
			},
			broker_filter_cost ={
				name      = L["Filter based on cost"],
				desc      = L["Skills with a base cost to train higher then the filter are not counted in the total. 0 means that the filter is not active."],
				type      = 'range',
				min		 = 0,
				max		 = 10000,
				softMin   = 0,
				softMax   = 5000,
				step		 = 10,
				order     = 1.3,
			},
			tooltip_display = {
				type = 'header',
				name = L["Tooltip Display"],
				desc = L["Specify what to display in the main tooltip"],
				order = 2,
			},
			reputation = {
				name      = L["Reputation"],
				desc      = L["Display the cheapest reputations in the tooltip"],
				type      = 'toggle',
				order     = 2.1,
			},
			display_cost = {
				name      = L["Cost to learn skills"],
				desc      = L["Choose how the cost to learn is displayed in the tooltips"],
				type      = 'select',
				values	 = { base = L['Base Cost'], cheapest = L['Cheapest Cost'], none = L['None'] },
				order     = 2.2,
			},
			total_learnable = {
				name      = L["Total Learnable"],
				desc      = L["Display the total number of skills that are trainable"],
				type      = 'toggle',
				order     = 2.3,
			},
			overall_cost = {
				name      = L["Overall Cost"],
				desc      = L["Display the total cost for the current trainable skills"],
				type      = 'toggle',
				order     = 2.4,
			},
			ability_req = {
				name      = L["Ability Requirement"],
				desc      = L["Display the missing ability requirement. Ex. Gnoming Engineering or Artisant Flying."],
				type      = 'toggle',
				order     = 2.5,
			},
			tooltip_scale = {
				name      = L["Scale"],
				desc      = L["Overall Scale for the tooltips"],
				type      = 'range',
				min		 = 0.5,
				max		 = 2,
				step		 = 0.05,
				order     = 2.6,
			},
			tooltip_display_filters = {
				type = 'header',
				name = L["Tooltip Display Filters"],
				desc = L["Set the filters for the main tooltip"],
				order = 3,
			},
			level_range = {
				name      = L["Level Range"],
				desc      = "",
				type      = 'range',
				min		 = 0,
				max		 = 85,
				softMin   = 0,
				softMax   = 10,
				step		 = 1,
				order     = 3.1,
			},
			skill_range = {
				name      = L["Skill Range"],
				desc      = "",
				min		 = 0,
				max		 = 450,
				softMin   = 0,
				softMax   = 40,
				step 		 = 5,
				type      = 'range',

				order     = 3.2,
			},
			filter_cost ={
				name      = L["Filter based on cost"],
				desc      = L["Skills with a base cost to train higher then the filter are not displayed. 0 means that the filter is not active."],
				type      = 'range',
				min		 = 0,
				max		 = 10000,
				softMin   = 0,
				softMax   = 5000,
				step		 = 10,
				order     = 3.3,
			},
		},
	}

	local function get(info)
		return Syllabus.db.profile[info[#info]]
	end

	local function set(info, arg1, arg2, arg3, arg4)
		Syllabus.db.profile[info[#info]] = arg1
		Syllabus:UpdateSkills()
	end

	for k, v in pairs(options.args) do
		if v.type ~= 'header' then
			v.get = v.get or get
			v.set = v.set or set
		end
	end

	-- Profile section
	--options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(Syllabus.db)

	-- Init the Blizzard options pannel
	_G.LibStub("AceConfig-3.0"):RegisterOptionsTable(MODNAME, options)
	_G.LibStub("AceConfigDialog-3.0"):AddToBlizOptions(MODNAME)

	-- Profile management
	local p_options = _G.LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)
	_G.LibStub("AceConfig-3.0"):RegisterOptionsTable(MODNAME..'-Profile', p_options)
	_G.LibStub("AceConfigDialog-3.0"):AddToBlizOptions(MODNAME..'-Profile', p_options.name, MODNAME)

	-- Profile callbacks
	self.db.RegisterCallback(self, "OnProfileChanged", "UpdateSkills")
	self.db.RegisterCallback(self, "OnProfileCopied", "UpdateSkills")
	self.db.RegisterCallback(self, "OnProfileReset", "UpdateSkills")


	-- About section (only if someone else has included LibAboutPanel)
	if _G.LibStub:GetLibrary("LibAboutPanel", true) then
		_G.LibStub:GetLibrary("LibAboutPanel").new(MODNAME, MODNAME)
	end

end
